@@ -14,13 +14,13 @@ def safe_import(name: str, package: str | None = None, member: str | None = None
     """
     mod = importlib.import_module(name, package=package)
     return getattr(mod, member) if member else mod
-def _unique_module_name(base: str, path: Path) -> str:
+def unique_module_name(base: str, path: Path) -> str:
     # Make a stable, unique name per file
     digest = hashlib.md5(str(path.resolve()).encode()).hexdigest()[:8]
     stem = path.stem.replace('-', '_')
     return f"_dyn.{base}.{stem}_{digest}"
 
-def _import_from_path(module_name: str, file_path: Path):
+def import_from_path(module_name: str, file_path: Path):
     spec = importlib.util.spec_from_file_location(module_name, str(file_path))
     if spec is None or spec.loader is None:
         raise ImportError(f"Could not load spec for {file_path}")
@@ -55,7 +55,7 @@ def get_imports(files: List[str],self=None) -> Dict[str, Dict[str, Any]]:
             seen_sysroots.add(str(sysroot))
 
         # 3) Compute dotted name from sysroot and import
-        dotted = _dotted_from(file_p, sysroot)
+        dotted = dotted_from(file_p, sysroot)
         try:
             mod = importlib.import_module(dotted)
         except Exception as e:
